Index: Mailman/Archiver/pipermail.py
--- Mailman/Archiver/pipermail.py.orig	2003-12-24 18:09:30 +0100
+++ Mailman/Archiver/pipermail.py	2005-04-30 09:07:16 +0200
@@ -115,9 +115,9 @@
         parentID = article.parentID
         if parentID is not None and self.articleIndex.has_key(parentID):
             parent = self.getArticle(archive, parentID)
-            myThreadKey = parent.threadKey + article.date + '-'
+            myThreadKey = parent.threadKey + article.date + '/' + article.msgid + '-'
         else:
-            myThreadKey = article.date + '-'
+            myThreadKey = article.date + '/' + article.msgid + '-'
         article.threadKey = myThreadKey
         key = myThreadKey, article.msgid
         self.setThreadKey(archive, key, article.msgid)
@@ -407,7 +407,7 @@
                 else:
                     parent = self.database.getArticle(self.archive,
                                                     article.parentID)
-                    article.threadKey = parent.threadKey+article.date+'-'
+                    article.threadKey = parent.threadKey + article.date + '/' + article.msgid + '-'
                 self.database.setThreadKey(self.archive,
                     (article.threadKey, article.msgid),
                     msgid)
@@ -615,9 +615,9 @@
             article.parentID = parentID = self.get_parent_info(arch, article)
             if parentID:
                 parent = self.database.getArticle(arch, parentID)
-                article.threadKey = parent.threadKey + article.date + '-'
+                article.threadKey = parent.threadKey + article.date + '/' + article.msgid + '-'
             else:
-                article.threadKey = article.date + '-'
+                article.threadKey = article.date + '/' + article.msgid + '-'
             key = article.threadKey, article.msgid
 
             self.database.setThreadKey(arch, key, article.msgid)
Index: Mailman/Commands/cmd_subscribe.py
--- Mailman/Commands/cmd_subscribe.py.orig	2002-11-21 06:37:25 +0100
+++ Mailman/Commands/cmd_subscribe.py	2005-04-30 09:07:16 +0200
@@ -76,6 +76,7 @@
     if password is None:
         password = Utils.MakeRandomPassword()
     if address is None:
+        h = None
         realname, address = parseaddr(res.msg['from'])
         if not address:
             # Fall back to the sender address
@@ -84,9 +85,13 @@
             res.results.append(_('No valid address found to subscribe'))
             return STOP
         # Watch for encoded names
-        h = make_header(decode_header(realname))
+        try:
+            h = make_header(decode_header(realname))
+        except UnicodeDecodeError:
+            # Just fall back to an empty real, it's not critical
+            h = ""
         # BAW: in Python 2.2, use just unicode(h)
-        realname = h.__unicode__()
+        realname = unicode(h)
         # Coerce to byte string if uh contains only ascii
         try:
             realname = realname.encode('us-ascii')
Index: Mailman/Defaults.py.in
--- Mailman/Defaults.py.in.orig	2004-04-25 04:30:03 +0200
+++ Mailman/Defaults.py.in	2005-04-30 09:07:16 +0200
@@ -770,6 +770,21 @@
 # list's config variable default_member_moderation.
 DEFAULT_NEW_MEMBER_OPTIONS = 256
 
+# Specify the type of passwords to use, when Mailman generates the passwords
+# itself, as would be the case for membership requests where the user did not
+# fill in a password, or during list creation, when auto-generation of admin
+# passwords was selected.
+#
+# Set this value to Yes for classic Mailman user-friendly(er) passwords.
+# These generate semi-pronounceable passwords which are easier to remember.
+# Set this value to No to use more cryptographically secure, but harder to
+# remember, passwords -- if your operating system and Python version support
+# the necessary feature (specifically that /dev/urandom be available).
+USER_FRIENDLY_PASSWORDS = Yes
+# This value specifies the default lengths of member and list admin passwords
+MEMBER_PASSWORD_LENGTH = 8
+ADMIN_PASSWORD_LENGTH = 10
+
 
 
 #####
Index: Mailman/Handlers/AvoidDuplicates.py
--- Mailman/Handlers/AvoidDuplicates.py.orig	2003-04-19 06:57:14 +0200
+++ Mailman/Handlers/AvoidDuplicates.py	2005-04-30 09:07:16 +0200
@@ -92,4 +92,6 @@
     msgdata['recips'] = newrecips
     # RFC 2822 specifies zero or one CC header
     del msg['cc']
-    msg['Cc'] = COMMASPACE.join([formataddr(i) for i in ccaddrs.values()])
+    newcc = COMMASPACE.join([formataddr(i) for i in ccaddrs.values()])
+    if newcc:
+        msg['Cc'] = newcc
Index: Mailman/Handlers/Decorate.py
--- Mailman/Handlers/Decorate.py.orig	2003-12-01 15:21:08 +0100
+++ Mailman/Handlers/Decorate.py	2005-04-30 09:07:16 +0200
@@ -156,6 +156,7 @@
     del msg['content-transfer-encoding']
     del msg['content-disposition']
     msg['Content-Type'] = 'multipart/mixed'
+    msg['Mime-version'] = '1.0'
 
 
 
Index: Mailman/Handlers/Scrubber.py
--- Mailman/Handlers/Scrubber.py.orig	2003-12-01 02:43:18 +0100
+++ Mailman/Handlers/Scrubber.py	2005-04-30 09:07:16 +0200
@@ -316,6 +316,8 @@
                     t = u.encode('ascii', 'replace')
                 try:
                     # Should use HTML-Escape, or try generalizing to UTF-8
+                    if len(charset) == 0:
+                        charset = 'us-ascii'
                     t = t.encode(charset, 'replace')
                 except (UnicodeError, LookupError, ValueError):
                     t = t.encode(lcset, 'replace')
Index: Mailman/ListAdmin.py
--- Mailman/ListAdmin.py.orig	2005-04-30 09:07:16 +0200
+++ Mailman/ListAdmin.py	2005-04-30 09:07:16 +0200
@@ -83,6 +83,8 @@
             except IOError, e:
                 if e.errno <> errno.ENOENT: raise
                 self.__db = {}
+                # put version number in new database
+                self.__db['version'] = IGN, mm_cfg.REQUESTS_FILE_SCHEMA_VERSION
 
     def __closedb(self):
         if self.__db is not None:
Index: Mailman/Queue/#Switchboard.py.rej#
--- /dev/null	2005-04-30 09:07:56 +0200
+++ Mailman/Queue/#Switchboard.py.rej#	2005-04-30 09:07:16 +0200
@@ -0,0 +1,12 @@
+@@ -259,7 +259,10 @@
+ 
+     def _ext_read(self, filename):
+         fp = open(filename)
+-        dict = marshal.load(fp)
++        try:
++            dict = marshal.load(fp)
++        except EOFError:
++            return {}
+         # Update from version 2 files
+         if dict.get('version', 0) == 2:
+             del dict['filebase']
Index: Mailman/Queue/OutgoingRunner.py
--- Mailman/Queue/OutgoingRunner.py.orig	2004-02-22 23:37:45 +0100
+++ Mailman/Queue/OutgoingRunner.py	2005-04-30 09:07:16 +0200
@@ -88,6 +88,7 @@
                 syslog('error', 'Cannot connect to SMTP server %s on port %s',
                        mm_cfg.SMTPHOST, port)
                 self.__logged = True
+            self._snooze(0)
             return True
         except Errors.SomeRecipientsFailed, e:
             # Handle local rejects of probe messages differently.
Index: Mailman/Queue/Switchboard.py.rej
--- /dev/null	2005-04-30 09:07:56 +0200
+++ Mailman/Queue/Switchboard.py.rej	2005-04-30 09:07:16 +0200
@@ -0,0 +1,20 @@
+***************
+*** 259,265 ****
+  
+      def _ext_read(self, filename):
+          fp = open(filename)
+-         dict = marshal.load(fp)
+          # Update from version 2 files
+          if dict.get('version', 0) == 2:
+              del dict['filebase']
+--- 259,268 ----
+  
+      def _ext_read(self, filename):
+          fp = open(filename)
++         try:
++             dict = marshal.load(fp)
++         except EOFError:
++             return {}
+          # Update from version 2 files
+          if dict.get('version', 0) == 2:
+              del dict['filebase']
Index: Mailman/Utils.py
--- Mailman/Utils.py.orig	2005-04-30 09:07:16 +0200
+++ Mailman/Utils.py	2005-04-30 09:07:16 +0200
@@ -680,7 +680,7 @@
     else:
         # See the note in Defaults.py concerning DEFAULT_HOST_NAME
         # vs. DEFAULT_EMAIL_HOST.
-        hostname = mm_cfg.DEFAULT_HOST_NAME or mm_cfg.DEFAULT_EMAIL_HOST
+        hostname = mm_cfg.DEFAULT_HOST_NAME or mm_cfg.DEFAULT_URL_HOST
         return hostname.lower()
 
 
Index: Mailman/htmlformat.py
--- Mailman/htmlformat.py.orig	2005-04-30 09:07:16 +0200
+++ Mailman/htmlformat.py	2005-04-30 09:07:16 +0200
@@ -299,7 +299,8 @@
         charset = 'us-ascii'
         if self.language and Utils.IsLanguage(self.language):
             charset = Utils.GetCharSet(self.language)
-        output = ['Content-Type: text/html; charset=%s\n' % charset]
+        output = ['Content-Type: text/html; charset=%s' % charset]
+        output.append('Cache-control: no-cache\n')
         if not self.suppress_head:
             kws.setdefault('bgcolor', self.bgcolor)
             tab = ' ' * indent
Index: bin/check_perms
--- bin/check_perms.orig	2003-03-31 22:07:55 +0200
+++ bin/check_perms	2005-04-30 09:07:16 +0200
@@ -81,7 +81,7 @@
     return os.stat(path)[ST_MODE]
 
 def statgidmode(path):
-    stat = os.stat(path)
+    stat = os.lstat(path)
     return stat[ST_MODE], stat[ST_GID]
 
 seen = {}
Index: bin/config_list
--- bin/config_list.orig	2003-11-25 00:08:19 +0100
+++ bin/config_list	2005-04-30 09:07:16 +0200
@@ -293,6 +293,11 @@
                                     in mm_cfg.OPTINFO.items()
                                     if validval & bitval]
                     gui._setValue(mlist, k, validval, fakedoc)
+                    # Ugly hack, but seems to be needed since
+                    # new_member_options isn't really a number in gui.
+                    # -- tfheen, 2003-12-06
+                    if k == "new_member_options":
+                        mlist.new_member_options = validval
             # BAW: when to do gui._postValidate()???
     finally:
         if savelist and not checkonly:
Index: bin/mailmanctl
--- bin/mailmanctl.orig	2004-02-03 23:26:08 +0100
+++ bin/mailmanctl	2005-04-30 09:07:16 +0200
@@ -416,6 +416,13 @@
         # won't be opening any terminal devices, don't do the ultra-paranoid
         # suggestion of doing a second fork after the setsid() call.
         os.setsid()
+
+        # Be sure to close any open std{in,out,err}
+        devnull = os.open('/dev/null', 0)
+        os.dup2(devnull, 0)
+        os.dup2(devnull, 1)
+        os.dup2(devnull, 2)
+
         # Instead of cd'ing to root, cd to the Mailman installation home
         os.chdir(mm_cfg.PREFIX)
         # Clear our file mode creation umask
Index: bin/newlist
--- bin/newlist.orig	2004-02-29 18:09:44 +0100
+++ bin/newlist	2005-04-30 09:07:16 +0200
@@ -62,6 +62,9 @@
 defined in your Defaults.py file or overridden by settings in mm_cfg.py).
 
 Note that listnames are forced to lowercase.
+
+The list admin address need to be a fully-qualified address, like
+owner@example.com, not just owner.
 """
 
 import sys
@@ -69,6 +72,7 @@
 import getpass
 import getopt
 import sha
+import grp
 
 import paths
 from Mailman import mm_cfg
@@ -97,6 +101,9 @@
 
 
 def main():
+    gid = grp.getgrnam(mm_cfg.MAILMAN_GROUP)[2]
+    if os.getgid() != mm_cfg.MAILMAN_GROUP:
+        os.setgid(gid)
     try:
         opts, args = getopt.getopt(sys.argv[1:], 'hql:',
                                    ['help', 'quiet', 'language='])
@@ -163,7 +170,7 @@
         except Errors.BadListNameError, s:
             usage(1, _('Illegal list name: %(s)s'))
         except Errors.EmailAddressError, s:
-            usage(1, _('Bad owner email address: %(s)s'))
+            usage(1, _('Bad owner email address: %(s)s.  Owner addresses need to be fully-qualified names, like "owner@example.com", not just "owner".'))
         except Errors.MMListAlreadyExistsError:
             usage(1, _('List already exists: %(listname)s'))
 
Index: bin/update
--- bin/update.orig	2005-04-30 09:07:16 +0200
+++ bin/update	2005-04-30 09:07:16 +0200
@@ -532,9 +532,11 @@
     file20 = os.path.join(mm_cfg.DATA_DIR, 'pending_subscriptions.db')
     file214 = os.path.join(mm_cfg.DATA_DIR, 'pending.pck')
     db = None
+    ver = None
     # Try to load the Mailman 2.0 file
     try:
         fp = open(file20)
+        ver = "20"
     except IOError, e:
         if e.errno <> errno.ENOENT: raise
     else:
@@ -546,6 +548,7 @@
         # Try to load the Mailman 2.1.x where x < 5, file
         try:
             fp = open(file214)
+            ver = "214"
         except IOError, e:
             if e.errno <> errno.ENOENT: raise
         else:
@@ -579,8 +582,12 @@
             # data[0] is the address being unsubscribed
             addrops_by_address.setdefault(data[0], []).append((key, val))
         elif op == Pending.SUBSCRIPTION:
-            # data[0] is a UserDesc object
-            addr = data[0].address
+            if ver == "20":
+                # data is tuple (emailaddr, password, digest)
+                addr = data[0]
+            else:
+                # data[0] is a UserDesc object
+                addr = data[0].address
             subs_by_address.setdefault(addr, []).append((key, val))
         elif op == Pending.RE_ENABLE:
             # data[0] is the mailing list's internal name
Index: messages/de/LC_MESSAGES/mailman.po
--- messages/de/LC_MESSAGES/mailman.po.orig	2004-04-04 19:03:05 +0200
+++ messages/de/LC_MESSAGES/mailman.po	2005-04-30 09:07:16 +0200
@@ -7006,7 +7006,7 @@
 "\">topics_bodylines_limit</a>\n"
 "             configuration variable."
 msgstr ""
-"Der Themenfilter kategorisiert jede eingehende e-Mailnachricht gemss href="
+"Der Themenfilter kategorisiert jede eingehende e-Mailnachricht gemss <a href="
 "\"http://www.python.org/doc/current/lib/module-re.html\">Filterregeln mit "
 "regulren Ausdrcken</a>, die Sie weiter unten festlegen knnen. Wenn die "
 "<code>Subject:</code> oder <code>Keywords:</code> Header der Nachricht mit "
@@ -7019,7 +7019,7 @@
 "nicht mit Sammelnachrichten.\n"
 " <p>Optional kann auch der Nachrichtentext auf Vorkommen von <code>Subject:</"
 "code> und <code>Keyword:</code> Header durchsucht werden. Spezifizieren Sie "
-"hierzu die Optionhref=\"?VARHELP=topics/topics_bodylines_limit"
+"hierzu die Option <a href=\"?VARHELP=topics/topics_bodylines_limit"
 "\">topics_bodylines_limit</a>."
 
 # Mailman/Gui/Topics.py:57
Index: messages/es/LC_MESSAGES/mailman.po
--- messages/es/LC_MESSAGES/mailman.po.orig	2004-03-16 07:04:06 +0100
+++ messages/es/LC_MESSAGES/mailman.po	2005-04-30 09:07:16 +0200
@@ -1944,7 +1944,7 @@
 
 #: Mailman/Cgi/create.py:200 bin/newlist:164
 msgid "Illegal list name: %(s)s"
-msgstr "Nombre de lista ilegal: %(opt)s"
+msgstr "Nombre de lista ilegal: %(s)s"
 
 #: Mailman/Cgi/create.py:205
 msgid ""
Index: scripts/driver
--- scripts/driver.orig	2005-04-30 09:07:16 +0200
+++ scripts/driver	2005-04-30 09:07:16 +0200
@@ -95,6 +95,15 @@
         module = getattr(pkg, scriptname)
         main = getattr(module, 'main')
         try:
+            import os
+            request_method = os.environ.get('REQUEST_METHOD')
+            if not request_method in ['GET', 'POST', 'HEAD']:
+                print "Status: 405 Method not allowed"
+                print "Content-type: text/plain"
+                print
+                print "The method is not allowed"
+                sys.exit()
+                
             try:
                 sys.stderr = logger
                 sys.stdout = tempstdout
Index: templates/#Makefile.in.rej#
--- /dev/null	2005-04-30 09:07:56 +0200
+++ templates/#Makefile.in.rej#	2005-04-30 09:07:16 +0200
@@ -0,0 +1,9 @@
+@@ -42,7 +42,7 @@
+ 
+ SHELL=		/bin/sh
+ 
+-LANGUAGES=	big5 ca cs de en es et eu fi fr gb hr hu it ja ko lt nl \
++LANGUAGES=	big5 ca cs da de en es et eu fi fr gb hr hu it ja ko lt nl \
+ 		no pl pt pt_BR ro ru sl sr sv uk
+ 
+ # Modes for directories and executables created by the install
Index: templates/Makefile.in
--- templates/Makefile.in.orig	2004-04-25 04:30:04 +0200
+++ templates/Makefile.in	2005-04-30 09:07:16 +0200
@@ -42,7 +42,7 @@
 
 SHELL=		/bin/sh
 
-LANGUAGES=	big5 ca cs de en es et eu fi fr gb hr hu it ja ko lt nl \
+LANGUAGES=	big5 ca cs da de en es et eu fi fr gb hr hu it ja ko lt nl \
 		no pl pt pt_BR ro ru sl sr sv tr uk
 
 # Modes for directories and executables created by the install
Index: templates/big5/admlogin.html
--- templates/big5/admlogin.html.orig	2001-06-08 16:14:36 +0200
+++ templates/big5/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,11 @@
 <html>
 <head>
   <title>%(listname)s ׾ ¥D</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/big5/listinfo.html
--- templates/big5/listinfo.html.orig	2002-03-25 07:33:20 +0100
+++ templates/big5/listinfo.html	2005-04-30 09:07:16 +0200
@@ -60,8 +60,8 @@
 	<td colspan="2">
 	  <P>
 	    [J(q\) <MM-List-Name> ׾½Ш̧Ƕ񧴤UCơC
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/ca/listinfo.html
--- templates/ca/listinfo.html.orig	2003-11-01 16:51:48 +0100
+++ templates/ca/listinfo.html	2005-04-30 09:07:16 +0200
@@ -53,8 +53,9 @@
       </TR>
       
   <tr> 
-    <td colspan="2">Per subscriure's ompli el seg&uuml;ent formulari. <MM-List-Subscription-Msg> 
+    <td colspan="2">Per subscriure's ompli el seg&uuml;ent formulari.
       <ul>
+	  <MM-List-Subscription-Msg>
         <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
           <TR> 
Index: templates/cs/admlogin.html
--- templates/cs/admlogin.html.orig	2002-02-12 01:04:09 +0100
+++ templates/cs/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>%(listname)s %(who)s pihlen</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/cs/listinfo.html
--- templates/cs/listinfo.html.orig	2002-12-13 19:13:44 +0100
+++ templates/cs/listinfo.html	2005-04-30 09:07:16 +0200
@@ -63,8 +63,8 @@
 	<td colspan="2">
 	  <P>
              Pro pihlen do konference <MM-List-Name> muste vyplnit nsledujc formul.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/cs/private.html
--- templates/cs/private.html.orig	2002-02-12 01:04:09 +0100
+++ templates/cs/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>Konference %(realname)s - pihlen pro pstup do privtnho archivu </title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/da/admlogin.html
--- templates/da/admlogin.html.orig	2003-09-22 05:52:33 +0200
+++ templates/da/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>%(listname)s %(who)s Loggin</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/da/listinfo.html
--- templates/da/listinfo.html.orig	2003-09-22 05:52:33 +0200
+++ templates/da/listinfo.html	2005-04-30 09:07:16 +0200
@@ -63,8 +63,8 @@
 	<td colspan="2">
 	  <P>
 	    Du kan tilmelde dig til <MM-List-Name> ved at udfylde den n&oslash;dvendig information nedenfor.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/da/private.html
--- templates/da/private.html.orig	2003-09-22 05:52:33 +0200
+++ templates/da/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>%(realname)s Login til Private Arkiver</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/de/admlogin.html
--- templates/de/admlogin.html.orig	2002-03-21 17:09:33 +0100
+++ templates/de/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>Anmeldung als %(listname)s-%(who)s</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/de/listinfo.html
--- templates/de/listinfo.html.orig	2004-01-06 10:58:28 +0100
+++ templates/de/listinfo.html	2005-04-30 09:07:16 +0200
@@ -63,8 +63,8 @@
 	  <P>
 	    Abonnieren Sie <MM-List-Name>, indem Sie das folgende Formular
  ausf&uuml;llen:
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/de/private.html
--- templates/de/private.html.orig	2001-10-02 16:15:38 +0200
+++ templates/de/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>Authentifizierung fr den Zugriff auf die Archive von %(realname)s</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/en/admlogin.html
--- templates/en/admlogin.html.orig	2001-05-31 21:25:10 +0200
+++ templates/en/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>%(listname)s %(who)s Authentication</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/en/listinfo.html
--- templates/en/listinfo.html.orig	2005-04-30 09:07:16 +0200
+++ templates/en/listinfo.html	2005-04-30 09:07:16 +0200
@@ -4,7 +4,7 @@
     <TITLE><MM-List-Name> Info Page</TITLE>
   
   </HEAD>
-  <BODY BGCOLOR="#ffffff">
+  <BODY>
 
     <P>
       <TABLE COLS="1" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/en/private.html
--- templates/en/private.html.orig	2001-06-01 19:12:14 +0200
+++ templates/en/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>%(realname)s Private Archives Authentication</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/es/admlogin.html
--- templates/es/admlogin.html.orig	2003-11-27 17:32:12 +0100
+++ templates/es/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>Autentificacin del %(who)s de %(listname)s </title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/es/listinfo.html
--- templates/es/listinfo.html.orig	2002-07-03 20:14:30 +0200
+++ templates/es/listinfo.html	2005-04-30 09:07:16 +0200
@@ -64,8 +64,8 @@
 	  <P>
 	    Subscribase a <MM-List-Name> rellenando los datos del
 	    siguiente formulario
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/es/private.html
--- templates/es/private.html.orig	2002-07-03 20:14:31 +0200
+++ templates/es/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
   <title>Autentificaci&oacute;n para los archivos privados de %(realname)s </title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/et/admlogin.html
--- templates/et/admlogin.html.orig	2003-09-28 18:46:23 +0200
+++ templates/et/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>%(listname)s %(who)s autoriseerimine</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/et/listinfo.html
--- templates/et/listinfo.html.orig	2003-09-28 18:46:23 +0200
+++ templates/et/listinfo.html	2005-04-30 09:07:16 +0200
@@ -59,8 +59,8 @@
 	<td colspan="2">
 	  <P>
 	   <MM-List-Name> tellimiseks titke jrgnev vorm
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/et/private.html
--- templates/et/private.html.orig	2003-09-28 18:46:23 +0200
+++ templates/et/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>%(realname)s privaatarhiiv</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/eu/admlogin.html
--- templates/eu/admlogin.html.orig	2003-12-01 17:07:41 +0100
+++ templates/eu/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>%(listname)s Zerrendako %(who)s Identifikatzen</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/eu/listinfo.html
--- templates/eu/listinfo.html.orig	2003-12-01 17:07:41 +0100
+++ templates/eu/listinfo.html	2005-04-30 09:07:16 +0200
@@ -62,8 +62,8 @@
 	<td colspan="2">
 	  <P>
 	    <MM-List-Name> posta zerrendan izena eman, ondoko eskaera-orria betez.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/eu/private.html
--- templates/eu/private.html.orig	2003-12-01 17:07:41 +0100
+++ templates/eu/private.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
     <title>%(realname)s Artxibo Pribatuak Egiaztatzea</title>
+<script>function sf(){document.f.username.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(action)s/">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(action)s/" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/fi/admlogin.html
--- templates/fi/admlogin.html.orig	2002-04-02 07:43:47 +0200
+++ templates/fi/admlogin.html	2005-04-30 09:07:16 +0200
@@ -2,9 +2,10 @@
 <html>
 <head>
   <title>%(listname)s %(who)s Authentication</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/fi/listinfo.html
--- templates/fi/listinfo.html.orig	2002-04-02 07:43:47 +0200
+++ templates/fi/listinfo.html	2005-04-30 09:07:16 +0200
@@ -63,8 +63,8 @@
 	<td colspan="2">
 	  <P>
 	    Liity listalle <MM-List-Name> tyttmll oheinen lomake.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/fi/private.html
--- templates/fi/private.html.orig	2002-04-02 07:43:47 +0200
+++ templates/fi/private.html	2005-04-30 09:07:16 +0200
@@ -2,8 +2,9 @@
 <html>
 <head>
     <title>%(realname)s Private Archives Authentication</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/fr/admlogin.html
--- templates/fr/admlogin.html.orig	2003-09-22 04:07:46 +0200
+++ templates/fr/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>Authentification %(who)s sur %(listname)s</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/fr/archtocentry.html
--- templates/fr/archtocentry.html.orig	2004-03-30 17:01:28 +0200
+++ templates/fr/archtocentry.html	2005-04-30 09:07:16 +0200
@@ -1,10 +1,11 @@
              
 	<tr>
-	<td>%(archivelabel)s:                            
-	<A href="%(archive)s/thread.html">[ Enfilade ]</a>               
-	<A href="%(archive)s/subject.html">[ Sujet ]</a>               
-	<A href="%(archive)s/author.html">[ Auteur ]</a>               
-	<A href="%(archive)s/date.html">[ Date ]</a>                          
+	<td>%(archivelabel)s:</td>
+        <td>
+	<A href="%(archive)s/thread.html">[ Enfilade ]</a>
+	<A href="%(archive)s/subject.html">[ Sujet ]</a>
+	<A href="%(archive)s/author.html">[ Auteur ]</a>
+	<A href="%(archive)s/date.html">[ Date ]</a>
 	</td>
-	%(textlink)s 
-        </tr>     
+	%(textlink)s
+        </tr>
Index: templates/fr/listinfo.html
--- templates/fr/listinfo.html.orig	2003-09-26 05:36:56 +0200
+++ templates/fr/listinfo.html	2005-04-30 09:07:16 +0200
@@ -61,8 +61,8 @@
       <p> 	    
 	Abonnez-vous &agrave; <MM-List-Name> en remplissant le formulaire 
 	      suivant. 	  
-	<MM-List-Subscription-Msg> 	 
       <ul>    
+	<MM-List-Subscription-Msg> 	 
         <table border="0" cellspacing="2" cellpadding="2" width="70%"
  height="112">
             <tr>
Index: templates/fr/private.html
--- templates/fr/private.html.orig	2003-09-22 04:07:47 +0200
+++ templates/fr/private.html	2005-04-30 09:07:16 +0200
@@ -2,8 +2,9 @@
 <head>
     <title>Authentifi:cation pour l'acc&egrave;s aux archives priv&eacute;es de
 %(realname)s</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/gb/admlogin.html
--- templates/gb/admlogin.html.orig	2001-07-27 23:04:08 +0200
+++ templates/gb/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>%(listname)s б Ա֤</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/gb/listinfo.html
--- templates/gb/listinfo.html.orig	2002-03-25 07:33:22 +0100
+++ templates/gb/listinfo.html	2005-04-30 09:07:16 +0200
@@ -60,8 +60,8 @@
 	<td colspan="2">
 	  <P>
 	    () <MM-List-Name> бϡ
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/hr/listinfo.html
--- templates/hr/listinfo.html.orig	2004-02-17 23:27:49 +0100
+++ templates/hr/listinfo.html	2005-04-30 09:07:16 +0200
@@ -63,8 +63,8 @@
 	  <P>
 	    Pretplatite se na <MM-List-Name> ispunjavanjem sljedee 
 	      forme.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/hu/#private.html.rej#
--- /dev/null	2005-04-30 09:07:56 +0200
+++ templates/hu/#private.html.rej#	2005-04-30 09:07:16 +0200
@@ -0,0 +1,11 @@
+@@ -1,8 +1,9 @@
+ <html>
+ <head>
+  <title>%(realname)s Privt archvum azonosts</title>
++<script>function sf(){document.f.adminpw.focus();}</script>
+ </head>
+-<body bgcolor="#ffffff">
++<body bgcolor="#ffffff" onLoad="sf()">
+ <FORM METHOD=POST ACTION="%(action)s">
+ %(message)s
+   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/hu/admlogin.html
--- templates/hu/admlogin.html.orig	2002-12-12 04:30:15 +0100
+++ templates/hu/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
    <title>%(listname)s %(who)s Azonosts</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/hu/listinfo.html
--- templates/hu/listinfo.html.orig	2002-12-20 05:28:00 +0100
+++ templates/hu/listinfo.html	2005-04-30 09:07:16 +0200
@@ -59,11 +59,10 @@
 	<td colspan="2">
 	  <P>
  	  Tltsd ki az albbi rlapot a(z) <MM-List-Name> listra val feliratkozshoz.	    
-	  <MM-List-Subscription-Msg>
 	  <P>Feliratkozs eltt krlek olvasd el a listaszerver
             <A HREF="/illik.html">illemtant</A>!
-
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/hu/private.html
--- templates/hu/private.html.orig	2004-01-26 08:17:48 +0100
+++ templates/hu/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
  <title>%(realname)s Privt archvum azonosts</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/it/admlogin.html
--- templates/it/admlogin.html.orig	2003-09-22 11:35:55 +0200
+++ templates/it/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
 <title>Autenticazione per %(who)s di %(listname)s</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/it/listinfo.html
--- templates/it/listinfo.html.orig	2002-11-25 21:29:47 +0100
+++ templates/it/listinfo.html	2005-04-30 09:07:16 +0200
@@ -63,8 +63,8 @@
 	<td colspan="2">
 	  <P>
 	    Iscriviti a <MM-List-Name> completando il seguente modulo.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/it/private.html
--- templates/it/private.html.orig	2003-09-22 11:35:56 +0200
+++ templates/it/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
 <title>Autenticazione per gli archivi privati di %(realname)s</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/ja/admlogin.html
--- templates/ja/admlogin.html.orig	2004-01-23 01:54:05 +0100
+++ templates/ja/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>%(listname)s %(who)s ǧ</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/ja/listinfo.html
--- templates/ja/listinfo.html.orig	2004-01-23 01:54:35 +0100
+++ templates/ja/listinfo.html	2005-04-30 09:07:16 +0200
@@ -65,8 +65,8 @@
 	  <P>
 	    <MM-List-Name> ؤ, 
             ʲΥեɬ׻Ƥ. 
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/ja/private.html
--- templates/ja/private.html.orig	2004-01-23 01:54:38 +0100
+++ templates/ja/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>%(realname)s ¸ ǧ</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/ko/admlogin.html
--- templates/ko/admlogin.html.orig	2002-03-28 19:32:11 +0100
+++ templates/ko/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>%(listname)s  </title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/ko/listinfo.html
--- templates/ko/listinfo.html.orig	2002-03-28 19:32:11 +0100
+++ templates/ko/listinfo.html	2005-04-30 09:07:16 +0200
@@ -63,8 +63,8 @@
 	<td colspan="2">
 	  <P>
 	      ׸ ä ּż <MM-List-Name>   Ͻʽÿ.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/ko/private.html
--- templates/ko/private.html.orig	2002-03-28 19:32:11 +0100
+++ templates/ko/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>%(realname)s   </title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/lt/admlogin.html
--- templates/lt/admlogin.html.orig	2002-12-24 20:05:13 +0100
+++ templates/lt/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>%(listname)s %(who)s prisijungimas</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/lt/listinfo.html
--- templates/lt/listinfo.html.orig	2002-12-26 20:48:42 +0100
+++ templates/lt/listinfo.html	2005-04-30 09:07:16 +0200
@@ -61,8 +61,8 @@
 	<td colspan="2">
 	  <P>
 	    Prisijunkite prie <MM-List-Name> upildydami iuos laukus:
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/lt/private.html
--- templates/lt/private.html.orig	2002-12-24 20:05:13 +0100
+++ templates/lt/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>%(realname)s privataus archyvo prisijungimas</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/nl/admlogin.html
--- templates/nl/admlogin.html.orig	2002-06-28 15:57:14 +0200
+++ templates/nl/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>%(listname)s %(who)s inloggen</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/nl/listinfo.html
--- templates/nl/listinfo.html.orig	2002-06-28 15:57:14 +0200
+++ templates/nl/listinfo.html	2005-04-30 09:07:16 +0200
@@ -57,8 +57,8 @@
 	<td colspan="2">
 	  <P>
 	    Om je aan te melden op de <MM-List-Name> Mailing lijst vul het onderstaande formulier in.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
@@ -123,4 +123,4 @@
   </table>
 <MM-Mailman-Footer>
 </BODY>
-</HTML>
\ No newline at end of file
+</HTML>
Index: templates/nl/private.html
--- templates/nl/private.html.orig	2002-06-28 15:57:14 +0200
+++ templates/nl/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>%(realname)s Prive Archief beveiligd</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/no/admlogin.html
--- templates/no/admlogin.html.orig	2001-08-17 23:43:43 +0200
+++ templates/no/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>%(listname)s %(who)s Innlogging</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/no/listinfo.html
--- templates/no/listinfo.html.orig	2002-11-19 10:20:43 +0100
+++ templates/no/listinfo.html	2005-04-30 09:07:16 +0200
@@ -62,8 +62,8 @@
 	<td colspan="2">
 	  <P>
 	    Du kan melde deg p&aring; <MM-List-Name> ved &aring; fylle ut n&oslash;dvendig informasjon nedenfor.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/no/private.html
--- templates/no/private.html.orig	2001-07-27 22:49:53 +0200
+++ templates/no/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>%(realname)s Innlogging til Private Arkiver</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/pl/admlogin.html
--- templates/pl/admlogin.html.orig	2003-04-20 06:52:59 +0200
+++ templates/pl/admlogin.html	2005-04-30 09:07:16 +0200
@@ -2,9 +2,10 @@
 <head>
   <title>Autoryzacja %(who)s %(listname)s</title>
 <meta http-equiv="content-type" content="text/html; charset=ISO-8859-2">
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/pl/listinfo.html
--- templates/pl/listinfo.html.orig	2003-12-30 19:10:06 +0100
+++ templates/pl/listinfo.html	2005-04-30 09:07:16 +0200
@@ -65,8 +65,8 @@
           W celu zapisania si na list <MM-List-Name> naley wypeni 
           poniszy formularz.
 
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/pl/private.html
--- templates/pl/private.html.orig	2003-04-20 06:52:59 +0200
+++ templates/pl/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>%(realname)s Private Archives Authentication</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/pt/admlogin.html
--- templates/pt/admlogin.html.orig	2003-04-09 07:09:01 +0200
+++ templates/pt/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>%(listname)s %(who)s Authentication</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/pt/listinfo.html
--- templates/pt/listinfo.html.orig	2003-04-09 07:09:01 +0200
+++ templates/pt/listinfo.html	2005-04-30 09:07:16 +0200
@@ -63,8 +63,8 @@
 	<td colspan="2">
 	  <P>
 	    Inscreva-se em <MM-List-Name> preenchendo o seguinte formulrio.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/pt/private.html
--- templates/pt/private.html.orig	2003-04-09 07:09:01 +0200
+++ templates/pt/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>%(realname)s Autenticao de Arquivos Privados</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/pt_BR/admlogin.html
--- templates/pt_BR/admlogin.html.orig	2003-09-22 04:07:48 +0200
+++ templates/pt_BR/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>Autenticao %(listname)s %(who)s</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/pt_BR/listinfo.html
--- templates/pt_BR/listinfo.html.orig	2003-09-22 05:58:28 +0200
+++ templates/pt_BR/listinfo.html	2005-04-30 09:07:16 +0200
@@ -63,8 +63,8 @@
 	  <P>
 	    Inscreva-se na lista <MM-List-Name> preenchendo o seguinte
 	      formulrio.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/pt_BR/private.html
--- templates/pt_BR/private.html.orig	2002-07-30 20:51:36 +0200
+++ templates/pt_BR/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>%(realname)s Autenticao de Arquivos Privados</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/ro/listinfo.html
--- templates/ro/listinfo.html.orig	2003-12-13 17:35:53 +0100
+++ templates/ro/listinfo.html	2005-04-30 09:07:16 +0200
@@ -60,8 +60,8 @@
 	  <P>
 	    V putei abona la lista de discuii <MM-List-Name> completnd formularul
 	    de mai jos.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/ru/admlogin.html
--- templates/ru/admlogin.html.orig	2002-09-25 01:09:41 +0200
+++ templates/ru/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
     <title> %(who)s   %(listname)s</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/ru/listinfo.html
--- templates/ru/listinfo.html.orig	2003-09-22 05:56:26 +0200
+++ templates/ru/listinfo.html	2005-04-30 09:07:16 +0200
@@ -51,8 +51,8 @@
         <td colspan="2">
           <P>
            ,      <MM-List-Name>,   .
-          <MM-List-Subscription-Msg>
           <ul>
+          <MM-List-Subscription-Msg>
               <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
                 WIDTH="70%" HEIGHT= "112">
                 <TR>
Index: templates/ru/newlist.txt
--- templates/ru/newlist.txt.orig	2002-09-25 00:12:39 +0200
+++ templates/ru/newlist.txt	2005-04-30 09:07:16 +0200
@@ -37,4 +37,4 @@
 .
 
       ,    
-mailman-owner@%(hostname)s.
+    %(siteowner)s.
Index: templates/ru/private.html
--- templates/ru/private.html.orig	2002-09-25 17:51:00 +0200
+++ templates/ru/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>        %(realname)s</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/sl/listinfo.html
--- templates/sl/listinfo.html.orig	2003-10-04 04:57:36 +0200
+++ templates/sl/listinfo.html	2005-04-30 09:07:16 +0200
@@ -63,8 +63,8 @@
 	  <P>
 	    Na seznam <MM-List-Name> se prijavite tako, da izpolnite
 	      obrazec.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/sr/admlogin.html
--- templates/sr/admlogin.html.orig	2003-09-22 05:52:34 +0200
+++ templates/sr/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>%(listname)s %(who)s Authentication</title>
-<meta http-equiv="Content-Type" content="text/html; charset=utf-8"></head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<meta http-equiv="Content-Type" content="text/html; charset=utf-8"><script>function sf(){document.f.adminpw.focus();}</script>
+</head>
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/sr/listinfo.html
--- templates/sr/listinfo.html.orig	2003-09-22 05:52:34 +0200
+++ templates/sr/listinfo.html	2005-04-30 09:07:16 +0200
@@ -52,8 +52,9 @@
       </TR>
       <tr>
 	<td colspan="2">
-	  <P> Укључујете се попуњавајући следећи формулар:<MM-List-Subscription-Msg> 
+	  <P> Укључујете се попуњавајући следећи формулар:
       <ul>
+	  <MM-List-Subscription-Msg>
         <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
           <TR> 
Index: templates/sr/private.html
--- templates/sr/private.html.orig	2003-09-22 05:52:34 +0200
+++ templates/sr/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 ﻿<html>
 <head>
     <title>Пријава за улаз у приватну архиву листе: %(realname)s </title>
-<meta http-equiv="Content-Type" content="text/html; charset=utf-8"></head>
-<body bgcolor="#ffffff">
+<meta http-equiv="Content-Type" content="text/html; charset=utf-8"><script>function sf(){document.f.adminpw.focus();}</script>
+</head>
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/sv/admlogin.html
--- templates/sv/admlogin.html.orig	2002-12-10 01:21:51 +0100
+++ templates/sv/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>%(listname)s %(who)s Inloggning</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/sv/listinfo.html
--- templates/sv/listinfo.html.orig	2002-12-24 15:07:17 +0100
+++ templates/sv/listinfo.html	2005-04-30 09:07:16 +0200
@@ -56,8 +56,9 @@
       </TR>
       <tr>
 	<td colspan="2">
-	  <P>Du kan anm&auml;la dig till <MM-List-Name> genom att fylla i n&ouml;dv&auml;ndig information nedan. 	  <MM-List-Subscription-Msg>
+	  <P>Du kan anm&auml;la dig till <MM-List-Name> genom att fylla i n&ouml;dv&auml;ndig information nedan.
 	  <ul>
+	<MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/sv/private.html
--- templates/sv/private.html.orig	2002-12-10 01:21:51 +0100
+++ templates/sv/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>%(realname)s Inloggning till Privata Arkiv</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: templates/tr/listinfo.html
--- templates/tr/listinfo.html.orig	2004-04-26 18:50:11 +0200
+++ templates/tr/listinfo.html	2005-04-30 09:07:16 +0200
@@ -63,8 +63,8 @@
 	  <P>
 	    <MM-List-Name> listesine aadaki formu doldurarak ye
 	      olabilirsiniz.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/uk/admlogin.html
--- templates/uk/admlogin.html.orig	2003-09-22 05:52:35 +0200
+++ templates/uk/admlogin.html	2005-04-30 09:07:16 +0200
@@ -1,9 +1,10 @@
 <html>
 <head>
   <title>Автентифікація користувача %(who)s списку листування %(listname)s</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
-<FORM METHOD=POST ACTION="%(path)s">
+<body bgcolor="#ffffff" onLoad="sf()">
+<FORM METHOD=POST ACTION="%(path)s" name="f">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
     <TR>
Index: templates/uk/listinfo.html
--- templates/uk/listinfo.html.orig	2003-12-01 01:15:42 +0100
+++ templates/uk/listinfo.html	2005-04-30 09:07:16 +0200
@@ -62,8 +62,8 @@
 	<td colspan="2">
 	  <P>
 	    Щоб підписатись на список листування <MM-List-Name> заповніть наступну форму.
-	  <MM-List-Subscription-Msg>
 	  <ul>
+	  <MM-List-Subscription-Msg>
 	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
 		WIDTH="70%" HEIGHT= "112">
 		<TR>
Index: templates/uk/private.html
--- templates/uk/private.html.orig	2003-09-22 05:52:35 +0200
+++ templates/uk/private.html	2005-04-30 09:07:16 +0200
@@ -1,8 +1,9 @@
 <html>
 <head>
     <title>Автентифікація доступу до закритого списку листування %(realname)s</title>
+<script>function sf(){document.f.adminpw.focus();}</script>
 </head>
-<body bgcolor="#ffffff">
+<body bgcolor="#ffffff" onLoad="sf()">
 <FORM METHOD=POST ACTION="%(action)s/">
 %(message)s
   <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
Index: Mailman/HTMLFormatter.py
--- Mailman/HTMLFormatter.py	2003-09-29 08:01:22.000000000 -0700
+++ Mailman/HTMLFormatter.py	2005-03-14 09:59:23.324177386 -0800
@@ -43,7 +43,7 @@
         realname = self.real_name
         hostname = self.host_name
         listinfo_link  = Link(self.GetScriptURL('listinfo'), realname).Format()
-        owner_link = Link('mailto:' + self.GetOwnerEmail(), ownertext).Format()
+        owner_link = Link('mailto:' + self.GetOwnerEmail(), realname + '-owner').Format()
         innertext = _('%(listinfo_link)s list run by %(owner_link)s')
         return Container(
             '<hr>',
